.. _asset:

===================================================
Analysis of Sequences of Synchronous EvenTs (ASSET)
===================================================

.. automodule:: elephant.asset.asset


References
----------

.. bibliography:: ../bib/elephant.bib
   :labelprefix: asset
   :keyprefix: asset-
   :style: unsrt
